/*
 Drums: 27 to 87
 
 To play "Sticks" (31):
 talkMIDI(0xB0, 0, 0x78); //Bank select: drums
 talkMIDI(0xC0, 5, 0); //Set instrument number (arbitrary)
 //Play note on channel 1 (0x90), some note value (note), middle velocity (60):
 noteOn(0, 31, 60);
 MIDI channel 9 reserved for percussion
 */
 
// major: root+4+7; minor: root+3+7

// Status  (8-bit, status plus channel)
// Channel voice messages
#define   NOTE_OFF           0x80      // key, velocity
#define   NOTE_ON            0x90      // key, velocity
#define   KEY_PRESSURE       0xA0      // key, pressure -- aftertouch
#define   CONTROLLER         0xB0      // controller num, value
#define   PROG_CHANGE        0xC0      // program number
#define   CHAN_PRESSURE      0xD0      // channel pressure -- aftertouch
#define   PITCH_BEND         0xE0      // high byte, low byte

// Control change messages
#define   CTRL_BANK          0x00      // Select bank of instruments
#define   CTRL_VOLUME        0x07      // Set volune (0-127)
#define   CTRL_PAN           0x0A      // Pan (63=center)
#define   CTRL_INSTRUMENT    0xC0      // Set instrument within bank
#define   CTRL_HOLD          0x40      // Hold
#define   CTRL_SUSTENUITO    0x42      // Sustenuto
#define   CTRL_REVERB_EFX    0x5B      // Reverb effects level
#define   CTRL_ALL_OFF       0x7B      // All notes off

// Instrument banks
#define   BANK_MELODIC       0x79
#define   BANK_PERCUSSION    0x78

// Some commonly used pitches
#define   NOTE_C4            60
#define   NOTE_A4            69

// Channels (can have up to 16)
#define   CHAN_1            0
#define   CHAN_2            1
#define   CHAN_3            2

// Pin I/O
//  These pins for the MP3/MIDI shield
#define   midiIn            3          // MIDI input
#define   resetPin          4          // Reset

//channel message 0xb0: parameter
//0x00: bank select (0 is default, 0x78 and 0x7f is drums, 0x79 melodic)
//0x06: RPN MSB: 0 = bend range, 2 = coarse tune
//0x07: channel volume
//0x0a: pan control
//0x0b: expression (changes volume)
//0x0c: effect control 1 (sets global reverb decay)
//0x26: RPN LSB: 0 = bend range
//0x40: hold1
//0x42: sustenuto
//0x5b effects level (channel reverb level)
//0x62,0x63,0x64,0x65: NRPN and RPN selects
//0x78: all sound off
//0x79: reset all controllers
//0x7b, 0x7c, 0x7d: all notes off
