// Channel voice messages (all are 8-bit, 128 and above)
#define   NOTE_OFF               0x80   // 2 bytes: key, velocity
#define   NOTE_ON                0x90   // 2 bytes: key, velocity
#define   CONTROLLER             0xB0   // 2 bytes: controller num, value

// Control change messages
#define   CTRL_BANK              0x00   // Select bank of instruments
#define   CTRL_VOLUME            0x07   // Set volune (0-127)
#define   CTRL_INSTRUMENT        0xC0   // Set instrument within bank
#define   CTRL_ALL_OFF           0x7B   // All notes off

// Instrument banks
#define   BANK_MELODIC           0x79   // "Melody" instruments
#define   BANK_PERCUSSION        0x78   // Percussion (drum) instruments

// General values
#define   Instrument             5      // Instrument, electric piano 2
#define   NOTE_C4                60     // Middle-C on piano (use with melodic)
#define   NOTE_A4                69     // A above middle-C (concert pitch A)
#define   HIGH_AGOGO             66     // High agogo (use with percussion)
#define   CHAN_1                 0      // Channel (1 of 16)

// Pin assignments
#define   midiIn                 3      // MIDI input
#define   resetPin               4      // Reset

byte m_velocity = 127;                  // Note velocity (volume)

#include <SoftwareSerial.h> 
SoftwareSerial MIDI(255, midiIn);       // Rx, Tx (Rx not used)

void setup() {
  MIDI.begin(31250);                   // Set up serial comm to MIDI
  resetMidi();                         // Reset MIDI device
}

void loop() {
  ctrlMIDI(CHAN_1, CTRL_VOLUME, m_velocity);     // Set channel volume
  ctrlMIDI(CHAN_1, CTRL_BANK, BANK_MELODIC);     // Select channel bank
  sendMIDI(CTRL_INSTRUMENT, Instrument, 0);      // Select instrument in bank
  noteOn(CHAN_1, NOTE_C4, m_velocity);           // Turn on note
  delay(1000);
  noteOff(CHAN_1, NOTE_C4,  m_velocity);         // Turn off note
  delay(1000);
}

// ---- Standard functions ----
// Turn note on (press key)
void noteOn(byte channel, byte note, byte attackVelo) {
  sendMIDI( (NOTE_ON | channel), note, attackVelo);
}

// Turn note off (release key)
void noteOff(byte channel, byte note, byte releaseVelo) {
  sendMIDI( (NOTE_OFF | channel), note, releaseVelo);
}

// Set controller value with channel
void ctrlMIDI(byte channel, byte data1, byte data2) {
  sendMIDI( (CONTROLLER | channel), data1, data2);
}

// Send bytes to MIDI device
void sendMIDI(byte cmd, byte data1, byte data2) {
  MIDI.write(cmd);
  MIDI.write(data1);
  // Pass only if valid 2nd byte
  if( (cmd & 0xF0) <= 0xB0 || (cmd & 0xF0) == 0xE0 )
    MIDI.write(data2);
}

// Reset MIDI device
void resetMidi() {
  pinMode(resetPin, OUTPUT);
  digitalWrite(resetPin, LOW);
  delay(100);
  digitalWrite(resetPin, HIGH);
  delay(100);
}
